@@ -9,7 +9,7 @@ extern int errno;
 #define MAXLINELEN 1024
 
 /* how many possible answers are there? */
-#define NUMBEROFCHOICES 4
+#define NUMBEROFCHOICES 5
 
 /* enum for "changemode()" */
 enum { GUESSMEANING, GUESSKANJI,TOGGLEKANA};
@@ -20,10 +20,12 @@ enum { GUESSMEANING, GUESSKANJI,TOGGLEKANA};
 
 #define ALLGRADES 0xfe
 #define ABOVESIXGRADE 0x80
-#define FULLWIDTH 320
+/* FULLWIDTH is startup size of an english translation button */
+#define FULLWIDTH 370
 
 #define MINKANJIALLOWED 0x2000
 #define MAXKANJIALLOWED 0x8000
+#define HAVE_AT_LEAST 9
 
 struct translationstruct {
 
