@@ -137,7 +137,7 @@ void MakeKanjiButtons(){
 		}
 		XtAddCallback(kanjiWidget[i],XtNcallback,kanjicallback,(XtPointer)i);
 	}
-	XtManageChildren(kanjiWidget,4);
+	XtManageChildren(kanjiWidget,NUMBEROFCHOICES);
 
 	/* * * * * * * * * * * * * * * * * * * * * * *
 	 * THE REST of the widgets are for the
@@ -145,7 +145,7 @@ void MakeKanjiButtons(){
 	 */
 	currentkanjiForm = XtVaCreateManagedWidget(
 			"curkanjiForm",boxWidgetClass,kanjiform,
-			XtNhorizDistance,40,
+			XtNhorizDistance,35,
 			XtNright,XawChainRight,XtNleft,XawChainRight,
 			XtNfromHoriz,kanjiWidget[NUMBEROFCHOICES-1],NULL);
 	currentkanjiGrade = XtVaCreateManagedWidget(
@@ -198,7 +198,7 @@ void MakeEnglishButtons(){
 		XtAddCallback(englishWidget[i],XtNcallback,englishcallback,(XtPointer) i);
 
 	}
-	XtManageChildren(englishWidget,4);
+	XtManageChildren(englishWidget,NUMBEROFCHOICES);
 }
 
 void initfonts(){
@@ -318,12 +318,14 @@ puts("Starting MakeWidgets");
 	*/
 	form = XtVaCreateManagedWidget("kdrill",formWidgetClass,
 					   toplevel,
-		      XtNx,200, XtNy,100,
-		      XtNvSpace,16,
-		      XtNhSpace,10,
-		      NULL);
-	kanjiform = XtVaCreateManagedWidget("kdrill",formWidgetClass,
-					   form, NULL);
+			XtNx,200, XtNy,100,
+			XtNvSpace,16,
+			XtNhSpace,10,
+			NULL);
+
+	kanjiform = XtVaCreateManagedWidget("kdrill",formWidgetClass, form,
+			XtNright,XawChainRight,
+			NULL);
 
 	display = XtDisplay(toplevel);
 
